@@ -75,12 +75,21 @@ sub translate {
                 %gettext,
             )
         );
-     if ( exists $arg_ref->{escape} ) {
-         $translation = HTML::Template::Compiled::Plugin::I18N->escape(
-             $translation,
-             $arg_ref->{escape},
-         );
-     }
+    if ( exists $arg_ref->{escape} ) {
+        $translation = HTML::Template::Compiled::Plugin::I18N->escape(
+            $translation,
+            $arg_ref->{escape},
+        );
+    }
+    if ( exists $arg_ref->{formatter} ) {
+        my $formatter_ref = $arg_ref->{formatter};
+        for my $formatter ( @{$formatter_ref} ) {
+            # Call here a formatter like Markdown
+            if (lc $formatter eq lc 'Markdown') {
+                # $translation = ... $tanslation;
+            }
+        }
+    }
     if ( exists $arg_ref->{unescaped} ) {
         $translation = HTML::Template::Compiled::Plugin::I18N->expand_unescaped(
             $translation,
@@ -88,11 +97,11 @@ sub translate {
         );
     }
 
-     return $translation;
+    return $translation;
 }
 
 1;
 
 __END__
 
-$Id$
\ No newline at end of file
+$Id: Translator.pm 163 2009-12-03 09:20:38Z steffenw $
\ No newline at end of file
